@@ -1,22 +1,26 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 """These are default parameters for some of the plotting functions in Imexam
-Maybe it would be better to put these along with the imexam functions into
-their own class which the connect class can import? Users could edit this file
-to set their own defaults before installation, they could script something that
-resets the dictionaries themselves, or we could create a method to let them set
-from a json or text file maybe
+Users can edit this file to set their own defaults before installation,
+they could script something that resets the dictionaries themselves,
+or we could create a method to let them set from a json or text file maybe
 """
 
 # aperture photometry parameters
 aper_phot_pars = {"function": ["aper_phot", ],
-                 "center": [True, "Center the object location using a 2d gaussian fit"],
-                 "width": [5, "Width of sky annulus in pixels"],
-                 "subsky": [True, "Subtract a sky background?"],
-                 "skyrad": [15, "Distance to start sky annulus is pixels"],
-                 "radius": [5, "Radius of aperture for star flux"],
-                 "zmag": [25., "zeropoint for the magnitude calculation"],
-                 }
+                  "center": [True, "Center the object location using a 2d gaussian fit"],
+                  "width": [5, "Width of sky annulus in pixels"],
+                  "subsky": [True, "Subtract a sky background?"],
+                  "skyrad": [15, "Distance to start sky annulus is pixels"],
+                  "radius": [5, "Radius of aperture for star flux"],
+                  "zmag": [25., "zeropoint for the magnitude calculation"],
+                  "genplot": [True, "Plot the apertures"],
+                  "title": [None, "Title of the plot"],
+                  "scale": ['zscale', "How to scale the image"],
+                  "color_min": [None, "Minimum color value"],
+                  "color_max": [None, "Maximum color value"],
+                  "cmap": ['Greys', "Matplotlib colormap to use"],
+                  }
 
 
 # box statistics
@@ -27,22 +31,24 @@ report_stat_pars = {"function": ["report_stat", ],
 
 # radial profile plots
 radial_profile_pars = {"function": ["radial_profile", ],
-                        "title": [None, "Title of the plot"],
-                        "xlabel": ["Radius", "The string for the xaxis label"],
-                        "ylabel": ["Flux", "The string for the yaxis label"],
-                        "pixels": [True, "Plot all pixels at each radius? (False bins the data)"],
-                        "fitplot": [False, "Overplot profile fit?"],
-                        "fittype": ["Gaussian2D", "Profile type to fit (Gaussian2D)"],
-                        "center": [True, "Solve for center using 2d Gaussian? [bool]"],
-                        "background": [False, "Subtract background? [bool]"],
-                        "skyrad": [10., "Background inner radius in pixels, from center of object"],
-                        "width": [5., "Background annulus width in pixels"],
-                        "magzero": [25., "magnitude zero point"],
-                        "rplot": [8., "Plotting radius in pixels"],
-                        "pointmode": [True, "plot points instead of lines? [bool]"],
-                        "marker": ["o", "The marker character to use, matplotlib style"],
-                        "getdata": [False, "print the plotted data values"]
-                        }
+                       "title": [None, "Title of the plot"],
+                       "xlabel": ["Radius", "The string for the xaxis label"],
+                       "ylabel": ["Flux", "The string for the yaxis label"],
+                       "pixels": [True, "Plot all pixels at each radius? (False bins the data)"],
+                       "fitplot": [True, "Overplot model fit?"],
+                       "func": ["Gaussian1D", "Model form to fit"],
+                       "center": [True, "Solve for center using 2d Gaussian? [bool]"],
+                       "background": [True, "Subtract background? [bool]"],
+                       "skyrad": [10., "Background inner radius in pixels, from center of object"],
+                       "width": [5., "Background annulus width in pixels"],
+                       "magzero": [25., "magnitude zero point"],
+                       "rplot": [8., "Plotting radius in pixels"],
+                       "pointmode": [True, "plot points instead of lines? [bool]"],
+                       "marker": ["o", "The marker character to use, matplotlib style"],
+                       "getdata": [False, "print the plotted data values"],
+                       "clip": [False, "Sigma clip by np.mean before center fitting?"],
+                       "sigma": [4.0, "sigma value for clipping during model fit"],
+                       }
 
 # curve of growth
 curve_of_growth_pars = {"function": ["curve_of_growth", ],
@@ -93,6 +99,8 @@ line_fit_pars = {"function": ["line_fit", ],
                  "logx": [False, "log scale x-axis?"],
                  "logy": [False, "log scale y-axis?"],
                  "center": [True, "Recenter around the local max"],
+                 "clip": [False, "Sigma clip by the mean before fitting?"],
+                 "sigma": [3.0, "sigma value for clipping"],
                  }
 
 # fit of column in image using model
@@ -104,11 +112,13 @@ column_fit_pars = {"function": ["column_fit", ],
                    "background": [False, "Solve for background? [bool]"],
                    "width": [10.0, "Background  width in pixels"],
                    "order": [1, "Polynomial order to fit, 1=line"],
-                   "rplot": [20., "Plotting radius in pixels"],
+                   "rplot": [15., "Plotting radius in pixels"],
                    "pointmode": [True, "plot points instead of lines? [bool]"],
                    "logx": [False, "log scale x-axis?"],
                    "logy": [False, "log scale y-axis?"],
                    "center": [True, "Recenter around the local max"],
+                   "clip": [False, "Sigma clip by the mean before fitting?"],
+                   "sigma": [3.0, "sigma value for clipping"],
                    }
 
 # contour plots
@@ -121,7 +131,7 @@ contour_pars = {"function": ["contour", ],
                 "floor": [None, "Minimum value to be contoured"],
                 "ceiling": [None, "Maximum value to be contoured"],
                 "ncontours": [8, "Number of contours to be drawn"],
-                "linestyle": ["--", "matplotlib linestyle"],
+                "linestyles": ["--", "matplotlib linestyle"],
                 "label": [True, "Label major contours with their values? [bool]"],
                 "cmap": ["viridis", "Colormap (matplotlib style) for image"],
                 }
